@@ -270,6 +270,9 @@ public:
 		for (int i : env.state) {
 			state.push_back(i);
 		}
+		for (int i : env.goalState) {
+			goalState.push_back(i);
+		}
 	}
 
 	void loadStatCatalog() {
@@ -776,6 +779,7 @@ PYBIND11_MODULE(probotest1, m) {
 		.def_readwrite("probeCountOnGas", &ProtossMacroEnv::gProbeCount)
 		.def_readwrite("state", &ProtossMacroEnv::state)
 		.def_readwrite("goalState", &ProtossMacroEnv::goalState)
+		//.def_readwrite("ACTION_SPACE", &ProtossMacroEnv::ACTION_SPACE)
         ;
 
 	pybind11::class_<Names>(m, "Names")
